==> ejc-zatopbpm-impl-3.0.0-20230919.072812-26-sources.jar: com/ejianc/zatopbpm/mq/consumer/ZatopBaseConsumer.java <==
package com.ejianc.zatopbpm.mq.consumer;

import javax.annotation.Resource;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.framework.mq.RabbitMqConfiguration;
import org.apache.commons.lang.ArrayUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.amqp.core.AcknowledgeMode;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.core.MessageProperties;
import org.springframework.amqp.core.Queue;
import org.springframework.amqp.rabbit.core.RabbitAdmin;
import org.springframework.amqp.rabbit.listener.SimpleMessageListenerContainer;
import org.springframework.amqp.rabbit.listener.api.ChannelAwareMessageListener;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;

import com.alibaba.fastjson.JSON;
import com.ejianc.framework.mq.common.MqMessage;
import com.rabbitmq.client.Channel;

public abstract  class ZatopBaseConsumer implements  InitializingBean,ChannelAwareMessageListener,DisposableBean {
    protected static Logger logger = LoggerFactory.getLogger(ZatopBaseConsumer.class);
    @Resource(name="rabbitAdmin")
    private RabbitAdmin rabbitAdmin;
    @Resource(name="rabbitConfig")
    private RabbitConfig rabbitConfig;
    @Autowired
    private RabbitMqConfiguration mqConfig;

    private SimpleMessageListenerContainer listenerContainer;
    public static final String DEFAULT_CHARSET = "UTF-8";

    public void afterPropertiesSet(){
        logger.info("------------------------------------消息队列监听启动------------------------------------");
        String[] queueNames = this.getQueueNames();
        if(ArrayUtils.isEmpty(queueNames)){
            logger.warn("消息队列为空");
            return;
        }
        logger.info("消息队列参数：----host：{}，port：{}，username：{}，virtualHost：{}",rabbitConfig.getConnectionFactory().getHost(),rabbitConfig.getConnectionFactory().getPort(),rabbitConfig.getConnectionFactory().getUsername(),rabbitConfig.getConnectionFactory().getVirtualHost());
        listenerContainer = new SimpleMessageListenerContainer();
        listenerContainer.setConnectionFactory(rabbitConfig.getConnectionFactory());
        Queue[] queues = new Queue[queueNames.length];
        for(int i=0,len=queueNames.length;i<len;i++){
            String queueName = queueNames[i];
            Queue queue = new Queue(queueName,true,false,false);
            rabbitAdmin.declareQueue(queue);
            queues[i] = queue;
        }
        listenerContainer.addQueues(queues);
        listenerContainer.setPrefetchCount(1);
        listenerContainer.setMaxConcurrentConsumers(mqConfig.getMaxConcurrentConsumers());
        listenerContainer.setConcurrentConsumers(mqConfig.getConcurrentConsumers());
        listenerContainer.setAcknowledgeMode(AcknowledgeMode.MANUAL);
        listenerContainer.setMessageListener(this);
        listenerContainer.start();
    }

    public void destroy(){
        if(listenerContainer!=null){
            listenerContainer.stop();
        }
    }

    public void onMessage(Message message, Channel channel) throws Exception {
        String msg = new String(message.getBody(),DEFAULT_CHARSET);
        MessageProperties msgProps = message.getMessageProperties();
        try{
            logger.info("----------msg:{}",msg);
            JSONObject mqMessage = JSONObject.parseObject(msg);
            if(mqMessage==null){
                logger.error("消息体为空，舍弃！");
            }else{
                doConsumeMsg(mqMessage);
                logger.debug("消息消费完成");
            }
            //确认接收到消息,丢弃
            channel.basicAck(msgProps.getDeliveryTag(), false);
        }catch(Exception ex){
            //收到消息消费报错，重新放回队列
            channel.basicAck(msgProps.getDeliveryTag(), true);
            logger.error("消息消费失败:",ex);
        }
    }
    protected abstract void doConsumeMsg(JSONObject mqMessage);

    protected abstract String[] getQueueNames();
}

==> ejc-zatopbpm-impl-3.0.0-20230927.070948-64-sources.jar: com/ejianc/zatopbpm/mq/consumer/ZatopBaseConsumer.java <==
package com.ejianc.zatopbpm.mq.consumer;

import javax.annotation.Resource;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.framework.mq.RabbitMqConfiguration;
import org.apache.commons.lang.ArrayUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.amqp.core.AcknowledgeMode;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.core.MessageProperties;
import org.springframework.amqp.core.Queue;
import org.springframework.amqp.rabbit.core.RabbitAdmin;
import org.springframework.amqp.rabbit.listener.SimpleMessageListenerContainer;
import org.springframework.amqp.rabbit.listener.api.ChannelAwareMessageListener;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;

import com.alibaba.fastjson.JSON;
import com.ejianc.framework.mq.common.MqMessage;
import com.rabbitmq.client.Channel;

public abstract  class ZatopBaseConsumer implements  InitializingBean,ChannelAwareMessageListener,DisposableBean {
    protected static Logger logger = LoggerFactory.getLogger(ZatopBaseConsumer.class);
    @Resource(name="rabbitAdmin")
    private RabbitAdmin rabbitAdmin;
    @Resource(name="rabbitConfig")
    private RabbitConfig rabbitConfig;
    @Autowired
    private RabbitMqConfiguration mqConfig;

    private SimpleMessageListenerContainer listenerContainer;
    public static final String DEFAULT_CHARSET = "UTF-8";

    public void afterPropertiesSet(){
        logger.info("------------------------------------消息队列监听启动------------------------------------");
        String[] queueNames = this.getQueueNames();
        if(ArrayUtils.isEmpty(queueNames)){
            logger.warn("消息队列为空");
            return;
        }
        logger.info("消息队列参数：----host：{}，port：{}，username：{}，virtualHost：{}",rabbitConfig.getConnectionFactory().getHost(),rabbitConfig.getConnectionFactory().getPort(),rabbitConfig.getConnectionFactory().getUsername(),rabbitConfig.getConnectionFactory().getVirtualHost());
        listenerContainer = new SimpleMessageListenerContainer();
        listenerContainer.setConnectionFactory(rabbitConfig.getConnectionFactory());
        Queue[] queues = new Queue[queueNames.length];
        for(int i=0,len=queueNames.length;i<len;i++){
            String queueName = queueNames[i];
            Queue queue = new Queue(queueName,true,false,false);
            rabbitAdmin.declareQueue(queue);
            queues[i] = queue;
        }
        listenerContainer.addQueues(queues);
        listenerContainer.setPrefetchCount(1);
        listenerContainer.setMaxConcurrentConsumers(mqConfig.getMaxConcurrentConsumers());
        listenerContainer.setConcurrentConsumers(mqConfig.getConcurrentConsumers());
        listenerContainer.setAcknowledgeMode(AcknowledgeMode.MANUAL);
        listenerContainer.setMessageListener(this);
        listenerContainer.start();
    }

    public void destroy(){
        if(listenerContainer!=null){
            listenerContainer.stop();
        }
    }

    public void onMessage(Message message, Channel channel) throws Exception {
        String msg = new String(message.getBody(),DEFAULT_CHARSET);
        MessageProperties msgProps = message.getMessageProperties();
        try{
            logger.info("----------mq收到的消费信息:{}",msg);
            JSONObject mqMessage = JSONObject.parseObject(msg);
            if(mqMessage==null){
                logger.error("消息体为空，舍弃！");
            }else{
                doConsumeMsg(mqMessage);
                logger.debug("消息消费完成");
            }
            //确认接收到消息,丢弃
            channel.basicAck(msgProps.getDeliveryTag(), false);
        }catch(Exception ex){
            //收到消息消费报错，重新放回队列
            channel.basicAck(msgProps.getDeliveryTag(), true);
            logger.error("消息消费失败:",ex);
        }
    }
    protected abstract void doConsumeMsg(JSONObject mqMessage);

    protected abstract String[] getQueueNames();
}
